@@ -411,7 +411,7 @@ accessx_status_applet_get_glyph_pixbuf (AccessxStatusApplet *sapplet,
 	g_object_unref (layout);
 	glyph_pixbuf = gdk_pixbuf_get_from_drawable (NULL, pixmap, 
 						     cmap, 0, 0, 0, 0, w, h);
-	gdk_pixmap_unref (pixmap);
+	g_object_unref (pixmap);
 	alpha_pixbuf = gdk_pixbuf_add_alpha (glyph_pixbuf, TRUE, bg->red >> 8, bg->green >> 8, bg->blue >> 8);
 	g_object_unref (G_OBJECT (glyph_pixbuf));
 	g_object_unref (G_OBJECT (cmap));
@@ -548,7 +548,7 @@ accessx_status_applet_bouncekeys_image (AccessxStatusApplet *sapplet, XkbAccessX
 				      gdk_pixbuf_get_height (glyph_pixbuf) - 1, 
 				      1., 1., 1.0, 1.0, GDK_INTERP_NEAREST, 255);
 
-		gdk_pixbuf_unref (glyph_pixbuf);
+		g_object_unref (glyph_pixbuf);
 	}
 	return icon_base;
 }
@@ -659,7 +659,7 @@ accessx_status_applet_update (AccessxStatusApplet *sapplet,
 		GdkPixbuf *pixbuf = accessx_status_applet_mousekeys_image (
 			sapplet, &event->state);
 		gtk_image_set_from_pixbuf (GTK_IMAGE (sapplet->mousefoo),  pixbuf);
-		gdk_pixbuf_unref (pixbuf);
+		g_object_unref (pixbuf);
 	}
 
 	if (notify_type & ACCESSX_STATUS_ENABLED) {
@@ -865,7 +865,7 @@ accessx_status_applet_altgraph_icon_set (AccessxStatusApplet *sapplet, GtkWidget
 				      gdk_pixbuf_get_width (glyph_pixbuf),
 				      gdk_pixbuf_get_height (glyph_pixbuf),
 				      0., 0., 1.0, 1.0, GDK_INTERP_NEAREST, alpha);
-		gdk_pixbuf_unref (glyph_pixbuf);
+		g_object_unref (glyph_pixbuf);
 		gtk_icon_source_set_pixbuf (source, pixbuf);
 		gtk_icon_source_set_state (source, states[i]);
 		gtk_icon_source_set_state_wildcarded (source, wildcarded);
@@ -896,8 +896,10 @@ accessx_applet_add_stock_icons (AccessxStatusApplet *sapplet, GtkWidget *widget)
 			filename = g_build_filename (ACCESSX_PIXMAPS_DIR,
 						     stock_icons[i].name,
 						     NULL);
-			if (g_file_test (filename, G_FILE_TEST_EXISTS | 
-					 G_FILE_TEST_IS_REGULAR)) {
+			if (g_file_test (filename, G_FILE_TEST_EXISTS) &&
+			    g_file_test (filename, G_FILE_TEST_IS_REGULAR)) {
+				gtk_icon_source_set_filename (source, filename);
+			} else {
 				GtkIconSet *default_set = 
 					gtk_icon_factory_lookup_default (GTK_STOCK_MISSING_IMAGE);
 				gtk_icon_source_set_pixbuf (source,
@@ -910,10 +912,7 @@ accessx_applet_add_stock_icons (AccessxStatusApplet *sapplet, GtkWidget *widget)
 								    widget,
 								    NULL));
 			}
-			else {
-				gtk_icon_source_set_filename (source, filename);
-				g_free (filename);
-			}
+			g_free (filename);
 			gtk_icon_source_set_state (source, stock_icons[i].state);
 			gtk_icon_source_set_state_wildcarded (source, stock_icons[i].wildcarded);
 			gtk_icon_set_add_source (icon_set, source);
@@ -1176,7 +1175,7 @@ accessx_status_applet_background (PanelApplet *a,
         gtk_widget_set_style (GTK_WIDGET (sapplet->applet), NULL);
         rc_style = gtk_rc_style_new ();
         gtk_widget_modify_style (GTK_WIDGET (sapplet->applet), rc_style);
-        gtk_rc_style_unref (rc_style);
+        g_object_unref (rc_style);
 
         switch (type) {
                 case PANEL_COLOR_BACKGROUND:
