@@ -16,7 +16,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Street #330, Boston, MA 02111-1307, USA.
  *
- $Id: battstat_applet.c 11390 2009-03-19 23:33:42Z callum $
+ $Id$
  */
 
 #ifdef HAVE_CONFIG_H
@@ -342,7 +342,7 @@ battstat_error_dialog( GtkWidget *applet, const char *msg )
   GtkWidget *dialog;
 
   dialog = gtk_message_dialog_new( NULL, 0, GTK_MESSAGE_ERROR,
-                                   GTK_BUTTONS_OK, msg);
+                                   GTK_BUTTONS_OK, "%s", msg);
 
   gtk_window_set_screen( GTK_WINDOW (dialog),
                          gtk_widget_get_screen (GTK_WIDGET (applet)) );
@@ -440,7 +440,7 @@ battery_full_notify (GtkWidget *applet)
 	
 	if (error)
 	{
-	   g_warning (error->message);
+	   g_warning ("%s", error->message);
 	   g_error_free (error);
 	}
 
