@@ -19,7 +19,10 @@
 
 #ifndef __GEYES_H__
 #define __GEYES_H__
-#include <gnome.h>
+
+#include <glib.h>
+#include <gdk-pixbuf/gdk-pixbuf.h>
+#include <gtk/gtk.h>
 #include <panel-applet.h>
 
 #define MAX_EYES 1000
@@ -33,14 +36,13 @@ typedef struct
 typedef struct 
 {
 	/* Applet */
-	GtkWidget   *about_dialog;
 	PanelApplet *applet;
 	GtkWidget   *vbox;
 	GtkWidget   *hbox;
 	GtkWidget   **eyes;
 	guint        timeout_id;
-	gint pointer_last_x;
-	gint pointer_last_y;
+	gint 	    *pointer_last_x;
+	gint 	    *pointer_last_y;
 
 	/* Theme */
 	GdkPixbuf *eye_image;
@@ -58,9 +60,6 @@ typedef struct
 
 	/* Properties */
 	EyesPropertyBox prop_box;
-
-	/* Tooltip */
-	GtkTooltips *tooltips;
 } EyesApplet;
 
 /* eyes.c */
